@@ -25,7 +25,7 @@ MOA_recommender <- function(model, control=NULL, ...){
   class(out) <- c(model, "MOA_recommender", "MOA_model")
   out$type <- model
   ## Create the model
-  out$moamodel <- .jnew(modelclass(out$type))  
+  out$moamodel <- .jnew(modelclass(out$type), class.loader=.rJava.class.loader)  
   ## Set MOA options
   if(inherits(control, "MOAmodelOptions")){
     if(control$model != out$type){
@@ -131,4 +131,4 @@ print.summary_MOA_recommender <- function(x, ...){
   cat(x$type, sep="\n")  
   cat(sprintf("number of users: %s, items: %s, ratings: %s", x$nr.users, x$nr.items, x$nr.rating), sep="\n")
   cat(sprintf("ratings min: %s, max: %s, mean: %s", x$rating.range[1], x$rating.range[2], x$rating.globalmean), sep="\n")
-}
\ No newline at end of file
+}
